@@ -5,19 +5,16 @@
 #' prints only the coefficients that are higher or lower than the given
 #' threshold.
 #'
-#' @param bg code{\linkS4class{SWD}} object used to compute the correlation
-#' matrix.
+#' @param bg \linkS4class{SWD} object used to compute the correlation matrix.
 #' @param method character. The method used to compute the correlation matrix,
 #' default is "spearman".
 #' @param cor_th numeric. If provided it prints only the coefficients that are
-#' higher or lower than the given threshold, default is \code{NULL}.
+#' higher or lower than the given threshold, default is `NULL`.
 #'
-#' @return A \code{\link[ggplot2]{ggplot}} object.
+#' @return A \link[ggplot2]{ggplot} object.
 #' @export
-#' @importFrom ggplot2 ggplot aes_ scale_fill_gradient2 theme_minimal theme
-#' element_text coord_fixed element_blank geom_text
-#' @importFrom stats cor
-#' @importFrom stringr str_to_title
+#' @importFrom rlang .data
+#' @importFrom ggplot2 ggplot aes
 #'
 #' @author Sergio Vignali
 #'
@@ -47,32 +44,35 @@ plotCor <- function(bg, method = "spearman", cor_th = NULL) {
                        remove_diagonal = FALSE)
   label <- paste0(stringr::str_to_title(method), "'s\ncoefficient")
 
-  heat_map <- ggplot(data = cor_matrix, aes_(~Var2, ~Var1, fill = ~value)) +
-    geom_tile() +
-    scale_fill_gradient2(low = "#2c7bb6", mid = "#ffffbf", high = "#d7191c",
-                         limit = c(-1, 1), name = label) +
-    theme_minimal() +
-    theme(axis.text.x = element_text(angle = 45, vjust = 1, size = 10,
-                                     hjust = 1),
-          axis.text.y = element_text(size = 10),
-          axis.title.x = element_blank(),
-          axis.title.y = element_blank(),
-          panel.grid.major = element_blank(),
-          text = element_text(colour = "#666666")) +
-    coord_fixed()
+  heat_map <- ggplot(data = cor_matrix, aes(x = .data$Var2, y = .data$Var1,
+                                            fill = .data$value)) +
+    ggplot2::geom_tile() +
+    ggplot2::scale_fill_gradient2(low = "#2c7bb6", mid = "#ffffbf",
+                                  high = "#d7191c", limit = c(-1, 1),
+                                  name = label) +
+    ggplot2::theme_minimal() +
+    ggplot2::theme(axis.text.x = ggplot2::element_text(angle = 45, vjust = 1,
+                                                       size = 10, hjust = 1),
+                   axis.text.y = ggplot2::element_text(size = 10),
+                   axis.title.y = ggplot2::element_blank(),
+                   panel.grid.major = ggplot2::element_blank(),
+                   text = ggplot2::element_text(colour = "#666666")) +
+    ggplot2::coord_fixed()
 
   if (is.null(cor_th)) {
     heat_map <- heat_map +
-      geom_text(data = cor_matrix, aes_(~Var2, ~Var1,
-                                        label = round(cor_matrix$value, 2)),
-                color = "black", size = 3)
+      ggplot2::geom_text(data = cor_matrix,
+                         aes(x = .data$Var2, y = .data$Var1,
+                             label = round(.data$value, 2)),
+                         color = "black", size = 3)
   } else {
     highly_correlated <- corVar(bg, method = method, cor_th = cor_th,
                                 order = FALSE, remove_diagonal = FALSE)
     heat_map <- heat_map +
-      geom_text(data = highly_correlated,
-                aes_(~Var2, ~Var1, label = round(highly_correlated$value, 2)),
-                color = "black", size = 3)
+      ggplot2::geom_text(data = highly_correlated,
+                         aes(x = .data$Var2, y = .data$Var1,
+                             label = round(.data$value, 2)),
+                         color = "black", size = 3)
   }
 
   return(heat_map)
