@@ -6,15 +6,14 @@
 #' as first column and the value of the variable importance as second column.
 #' @param color character. The color of the bar plot, default is grey.
 #'
-#' @return A \code{\link[ggplot2]{ggplot}} object
+#' @return A \link[ggplot2]{ggplot} object.
 #' @export
-#' @importFrom ggplot2 ggplot aes_string ylab scale_y_continuous geom_bar
-#' coord_flip labs theme_minimal theme element_text
+#' @importFrom rlang .data
+#' @importFrom ggplot2 ggplot aes
 #'
 #' @author Sergio Vignali
 #'
 #' @examples
-#' \donttest{
 #' # Acquire environmental variables
 #' files <- list.files(path = file.path(system.file(package = "dismo"), "ex"),
 #'                     pattern = "grd", full.names = TRUE)
@@ -39,7 +38,6 @@
 #'
 #' # Plot variable importance with custom color
 #' plotVarImp(vi, color = "red")
-#' }
 plotVarImp <- function(df, color = "grey") {
 
   if (!requireNamespace("scales", quietly = TRUE)) {
@@ -51,13 +49,14 @@ plotVarImp <- function(df, color = "grey") {
   df <- df[order(df[, 2]), ]
   df[, 2] <- df[, 2] / 100
   df[, 1] <- factor(df[, 1], levels = df[, 1])
-  my_plot <- ggplot(df, aes_string(x = "Variable", y = colnames(df)[2])) +
-    labs(x = "", y = sub("_", " ", colnames(df)[2])) +
-    scale_y_continuous(labels = scales::percent) +
-    geom_bar(position = "dodge", stat = "identity", fill = color) +
-    coord_flip() +
-    theme_minimal() +
-    theme(text = element_text(colour = "#666666"))
+  y_name <- colnames(df)[2]
+  my_plot <- ggplot(df, aes(x = .data$Variable, y = .data[[y_name]])) +
+    ggplot2::labs(x = "", y = sub("_", " ", y_name)) +
+    ggplot2::scale_y_continuous(labels = scales::percent) +
+    ggplot2::geom_bar(position = "dodge", stat = "identity", fill = color) +
+    ggplot2::coord_flip() +
+    ggplot2::theme_minimal() +
+    ggplot2::theme(text = ggplot2::element_text(colour = "#666666"))
 
   return(my_plot)
 }
