@@ -1,5 +1,4 @@
 skip_on_cran()
-skip_on_appveyor()
 
 # .get_fc_args
 test_that("The correct fc arguments are created", {
@@ -125,8 +124,7 @@ test_that("The correct categorical feature is created", {
   expect_equal(.categorical(2, 1), 0)
 })
 
-skip_on_travis()
-skip_on_appveyor()
+skip_on_ci()
 skip_on_covr()
 
 #.train
